==> dl.php?src=linea21_1_8.zip: linea21/languages/it/lang_publication.utf-8.php <==
<?php
/**
 * @package linea21\languages\it
 * @author $Author$ - Alessandra Rossi & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['publication']['section'] = "pubblicazione";


/*	nommage des modules
 *  	*/
$lang['publication']['name']='pubblicazione';
$lang['publication']['name2']='pubblicazioni';
$lang['publication']['confirm_add'] = "Aggiunta di una pubblicazione avvenuta con successo\n";
$lang['publication']['confirm_mod'] = "Modifica della pubblicazione avvenuta con successo\n";
$lang['publication']['confirm_sup'] ="Eliminazione della pubblicazione avvenuta con successo\n";


/*	nommage rubrique module
 *  	*/
$lang['publication']['add']= 'Aggiunta di una '.$lang['publication']['name'];
$lang['publication']['mod']= 'Modifica di una '.$lang['publication']['name'];
$lang['publication']['sup']= 'Eliminazione di '.$lang['publication']['name'];
$lang['publication']['det']= 'Dettagli di '.$lang['publication']['name'];
$lang['publication']['list']= 'Consultazione delle pubblicazioni';


/*	nommage public
 *  	*/
$lang['publication']['next_part']='Visualizzare la sezione successiva ';
$lang['publication']['prev_part']='Visualizzare la sezione precedente ';
$lang['publication']['goto']='Vai a ';
/*	nommage rubrique add / mod /det
 *  	*/
$lang['publication']['add_title']='Inserimento delle informazioni del nuovo '.$lang['publication']['name'];
$lang['publication']['mod_title']='Modifica delle informazioni di '.$lang['publication']['name'];

$lang['publication']['h1_public_comment']='Descrivendo lo stato dei luoghi, fissando la posta in gioco e sollecitando delle riflessioni su dei casi concreti, le cartelle sapranno perfezionare le vostre conoscenze in materia di sviluppo sostenibile.';

/*	check integrité des données
 *  	*/
$lang['publication']['no_title'] = 'Devi dare un titolo alla nuova pubblicazione';
$lang['publication']['no_resume'] = 'Devi dare un\'intestazione alla pubblicazione';
$lang['publication']['no_theme'] = 'La pubblicazione deve essere associata a un tema';
$lang['publication']['no_scale'] = 'La pubblicazione deve essere associata a una scala';
$lang['publication']['no_author'] = 'Devi nominare un redattore di pubblicazione';
$lang['publication']['author_not_valid'] = 'Il reddattore scelto non esiste o il suo nome non è scritto correttamente';
$lang['publication']['author_not_rights'] = 'Il redattore scelto non ha i diritti necessari';

/*	nommage élément rubrique
 *  	*/
$lang['publication']['title']='titolo';
$lang['publication']['resume']='intestazione';
$lang['publication']['theme']='tema da associare';
$lang['publication']['scale']='scala da associare';
$lang['publication']['statut']='stato di pubblicazione';
$lang['publication']['comment']='commenti';

$lang['publication']['template']='modulo di presentazione';
$lang['publication']['photouri']='immagine(i) associata(e)';
$lang['publication']['visu1']='immagine n°1';
$lang['publication']['visu2']='immagine n°2';
$lang['publication']['author']='redattore';
$lang['publication']['published_on']='data di pubblicazione';
$lang['publication']['not_published']='non pubblicato';

$lang['publication']['generals']='Informazioni generali';
$lang['publication']['parts']='Dettaglio della pubblicazione';
$lang['publication']['listing']='Cartelle Linea21';
$lang['publication']['link_res']='Link associati alla pubblicazione';
$lang['publication']['biblio_res']='Risorse bibliografiche';
$lang['publication']['multi_res']='Risorse multimediali';
$lang['publication']['summary']='summary'; // @todo translation


/*	nommage quickbox
 *  	*/
$lang['publication']['qb_titleadd']=' ultime aggiunte effettuate';
$lang['publication']['qb_titlemod']=' ultime modifiche effettuate';
$lang['publication']['qb_titlesup']=' ultime eliminazioni effettuate';
$lang['publication']['qb_titlepubli']=' ultime pubblicazioni effettuate';


/*	divers
 *  	*/

$lang['publication']['nb_total']='le cartelle sono archiviate nel data base.';
$lang['publication']['statut_filter']='visualizzare per status';
$lang['publication']['part_number']='sezione ';
$lang['publication']['part_number2']='sezione ';
$lang['publication']['description']='descrizione';
$lang['publication']['all']='Visualizzare la lista completa';
$lang['publication']['noresult']='nessuna pubblicazione corrisponde ai criteri di selezione ';
$lang['news']['template_1']='Testo + foto a sinistra';
$lang['news']['template_2']='Testo + foto a destra';
$lang['news']['template_3']='Solo testo';


/*	textes modules annexes
 *  	*/
$lang['publication']['add_new_part']="Aggiungere una nuova sezione alla pubblicazione corrente";
$lang['publication']['add_new_linkres']="Associare un nouvo link alla pubblicazione corrente";
$lang['publication']['add_new_multires']="Associare un nouvo documento numerico alla pubblicazione corrente";
$lang['publication']['add_new_bibliores']="Associare un nuovo riferimento bibliografico alla pubblicazione corrente";

$lang['publication']['no_link']="Nessun sito internet è attualmente associato alla pubblicazione";
$lang['publication']['del_link']="Elimina il link";
$lang['publication']['mod_link']="Modifica il link";

$lang['publication']['no_multi']="Nessun documento multimediale è attualmente associato alla pubblicazione";
$lang['publication']['del_multi']="Eliminare il documento numerico";
$lang['publication']['mod_multi']="Modificare il documento numerico";

$lang['publication']['no_biblio']="Nessun riferimento bibliografico è attualmente associato alla pubblicazione";
$lang['publication']['del_biblio']="Eliminare il riferimento bibliografico";
$lang['publication']['mod_biblio']="Modificare il riferimento bibliografico";

$lang['publication']['no_part']="Attualmente la pubblicazione non contiene alcuna sezione";
$lang['publication']['del_part']="Eliminare la sezione";
$lang['publication']['mod_part']="Modificare la sezione";






/*	rubrique d'aide

*  	*/
$lang['publication']['help_add1']='Per aggiungere una pubblicazione, devi inserire le informazioni richieste nel modulo qui sotto.';
$lang['publication']['help_add2']='Dopo aver convalidato il formulario di aggiunta, controlla i dati nel riepilogo';
$lang['publication']['help_add3']='Se il riepilogo non ti soddisfa, clicca su \'modifica i parametri\' per modificare di nuovo i dati';

$lang['publication']['help_list1']='Per visualizzare il dettaglio di una pubblicazione, clicca sul titolo della medesima';
$lang['publication']['help_list2']='Puoi eliminare una pubblicazione cliccando sull\'icona di cancellazione associata';
$lang['publication']['help_list3']='Puoi modificare una pubblicazione cliccando sull\'icona di modifica associata';
$lang['publication']['help_list4']='Puoi utilizzare il filtro \'per status\' per visualizzare le cartelle desiderate';
$lang['publication']['help_list5']='Per aggiungere una pubblicazione, clicca su \'aggiungere una pubblicazione\' nella barra degli strumenti';


$lang['publication']['help_mod1']='Puoi modificare l\'insieme dei campi che ti sono accessibili nel modulo qui sotto';
$lang['publication']['help_mod2']='Dopo aver convalidato il modulo di modifica, controlla le informazioni inserite nel riepilogo';
$lang['publication']['help_mod3']='Se il riepilogo non ti soddisfa, clicca su \'modifica i parametri\' per modificare di nuovo i dati';


$lang['publication']['help_det1']='Puoi modificare le informazioni generali di questa pubblicazione cliccando sull\'icona di modifica associata';
$lang['publication']['help_det2']='Puoi eliminare questa pubblicazione cliccando sull\'icona di cancellazione associata';
$lang['publication']['help_det3']='Per visualizzare le sezioni che compongono la pubblicazione, i link associati, i documenti multimediali e le risorse bibliografiche, clicca su visualizza queste informazioni in basso nella pagina';
$lang['publication']['help_det4']='Per Aggiungere-Modificare-Eliminare le sezioni che compongono la pubblicazione, i link associati, i documenti multimediali e le risorse bibliografiche, clicca sulle icone che sono loro associate';

$lang['publication']['help_sup1']='Se non desideri confermare la cancellazione di questa pubblicazione, clicca su \'Annulla\'';


?>

==> dl.php?src=linea21_2_3_0.zip: linea21/languages/it/lang_publication.utf-8.php <==
<?php
/**
 * @package linea21\languages\it
 * @author $Author$ - Alessandra Rossi & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['publication']['section'] = "pubblicazione";


/*	nommage des modules
 *  	*/
$lang['publication']['name']='pubblicazione';
$lang['publication']['name2']='pubblicazioni';
$lang['publication']['confirm_add'] = "Aggiunta di una pubblicazione avvenuta con successo\n";
$lang['publication']['confirm_mod'] = "Modifica della pubblicazione avvenuta con successo\n";
$lang['publication']['confirm_sup'] ="Eliminazione della pubblicazione avvenuta con successo\n";


/*	nommage rubrique module
 *  	*/
$lang['publication']['add']= 'Aggiunta di una '.$lang['publication']['name'];
$lang['publication']['mod']= 'Modifica di una '.$lang['publication']['name'];
$lang['publication']['sup']= 'Eliminazione di '.$lang['publication']['name'];
$lang['publication']['det']= 'Dettagli di '.$lang['publication']['name'];
$lang['publication']['list']= 'Consultazione delle pubblicazioni';


/*	nommage public
 *  	*/
$lang['publication']['next_part']='Visualizzare la sezione successiva ';
$lang['publication']['prev_part']='Visualizzare la sezione precedente ';
$lang['publication']['goto']='Vai a ';
/*	nommage rubrique add / mod /det
 *  	*/
$lang['publication']['add_title']='Inserimento delle informazioni del nuovo '.$lang['publication']['name'];
$lang['publication']['mod_title']='Modifica delle informazioni di '.$lang['publication']['name'];

$lang['publication']['h1_public_comment']='Descrivendo lo stato dei luoghi, fissando la posta in gioco e sollecitando delle riflessioni su dei casi concreti, le cartelle sapranno perfezionare le vostre conoscenze in materia di sviluppo sostenibile.';

/*	check integrité des données
 *  	*/
$lang['publication']['no_title'] = 'Devi dare un titolo alla nuova pubblicazione';
$lang['publication']['no_resume'] = 'Devi dare un\'intestazione alla pubblicazione';
$lang['publication']['no_level'] = 'La pubblicazione deve essere associata a un livello';
$lang['publication']['no_scale'] = 'La pubblicazione deve essere associata a una scala';
$lang['publication']['no_author'] = 'Devi nominare un redattore di pubblicazione';
$lang['publication']['author_not_valid'] = 'Il reddattore scelto non esiste o il suo nome non è scritto correttamente';
$lang['publication']['author_not_rights'] = 'Il redattore scelto non ha i diritti necessari';

/*	nommage élément rubrique
 *  	*/
$lang['publication']['title']='titolo';
$lang['publication']['resume']='intestazione';
$lang['publication']['level']='livello da associare';
$lang['publication']['scale']='scala da associare';
$lang['publication']['statut']='stato di pubblicazione';
$lang['publication']['comment']='commenti';

$lang['publication']['template']='modulo di presentazione';
$lang['publication']['photouri']='immagine(i) associata(e)';
$lang['publication']['visu1']='immagine n°1';
$lang['publication']['visu2']='immagine n°2';
$lang['publication']['author']='redattore';
$lang['publication']['published_on']='data di pubblicazione';
$lang['publication']['not_published']='non pubblicato';

$lang['publication']['generals']='Informazioni generali';
$lang['publication']['parts']='Dettaglio della pubblicazione';
$lang['publication']['listing']='Cartelle Linea21';
$lang['publication']['link_res']='Link associati alla pubblicazione';
$lang['publication']['biblio_res']='Risorse bibliografiche';
$lang['publication']['multi_res']='Risorse multimediali';
$lang['publication']['summary']='summary'; // @todo translation


/*	nommage quickbox
 *  	*/
$lang['publication']['qb_titleadd']=' ultime aggiunte effettuate';
$lang['publication']['qb_titlemod']=' ultime modifiche effettuate';
$lang['publication']['qb_titlesup']=' ultime eliminazioni effettuate';
$lang['publication']['qb_titlepubli']=' ultime pubblicazioni effettuate';


/*	divers
 *  	*/

$lang['publication']['nb_total']='le cartelle sono archiviate nel data base.';
$lang['publication']['statut_filter']='visualizzare per status';
$lang['publication']['part_number']='sezione ';
$lang['publication']['part_number2']='sezione ';
$lang['publication']['description']='descrizione';
$lang['publication']['all']='Visualizzare la lista completa';
$lang['publication']['noresult']='nessuna pubblicazione corrisponde ai criteri di selezione ';
$lang['news']['template_1']='Testo + foto a sinistra';
$lang['news']['template_2']='Testo + foto a destra';
$lang['news']['template_3']='Solo testo';


/*	textes modules annexes
 *  	*/
$lang['publication']['add_new_part']="Aggiungere una nuova sezione alla pubblicazione corrente";
$lang['publication']['add_new_linkres']="Associare un nouvo link alla pubblicazione corrente";
$lang['publication']['add_new_multires']="Associare un nouvo documento numerico alla pubblicazione corrente";
$lang['publication']['add_new_bibliores']="Associare un nuovo riferimento bibliografico alla pubblicazione corrente";

$lang['publication']['no_link']="Nessun sito internet è attualmente associato alla pubblicazione";
$lang['publication']['del_link']="Elimina il link";
$lang['publication']['mod_link']="Modifica il link";

$lang['publication']['no_multi']="Nessun documento multimediale è attualmente associato alla pubblicazione";
$lang['publication']['del_multi']="Eliminare il documento numerico";
$lang['publication']['mod_multi']="Modificare il documento numerico";

$lang['publication']['no_biblio']="Nessun riferimento bibliografico è attualmente associato alla pubblicazione";
$lang['publication']['del_biblio']="Eliminare il riferimento bibliografico";
$lang['publication']['mod_biblio']="Modificare il riferimento bibliografico";

$lang['publication']['no_part']="Attualmente la pubblicazione non contiene alcuna sezione";
$lang['publication']['del_part']="Eliminare la sezione";
$lang['publication']['mod_part']="Modificare la sezione";






/*	rubrique d'aide

*  	*/
$lang['publication']['help_add1']='Per aggiungere una pubblicazione, devi inserire le informazioni richieste nel modulo qui sotto.';
$lang['publication']['help_add2']='Dopo aver convalidato il formulario di aggiunta, controlla i dati nel riepilogo';
$lang['publication']['help_add3']='Se il riepilogo non ti soddisfa, clicca su \'modifica i parametri\' per modificare di nuovo i dati';

$lang['publication']['help_list1']='Per visualizzare il dettaglio di una pubblicazione, clicca sul titolo della medesima';
$lang['publication']['help_list2']='Puoi eliminare una pubblicazione cliccando sull\'icona di cancellazione associata';
$lang['publication']['help_list3']='Puoi modificare una pubblicazione cliccando sull\'icona di modifica associata';
$lang['publication']['help_list4']='Puoi utilizzare il filtro \'per status\' per visualizzare le cartelle desiderate';
$lang['publication']['help_list5']='Per aggiungere una pubblicazione, clicca su \'aggiungere una pubblicazione\' nella barra degli strumenti';


$lang['publication']['help_mod1']='Puoi modificare l\'insieme dei campi che ti sono accessibili nel modulo qui sotto';
$lang['publication']['help_mod2']='Dopo aver convalidato il modulo di modifica, controlla le informazioni inserite nel riepilogo';
$lang['publication']['help_mod3']='Se il riepilogo non ti soddisfa, clicca su \'modifica i parametri\' per modificare di nuovo i dati';


$lang['publication']['help_det1']='Puoi modificare le informazioni generali di questa pubblicazione cliccando sull\'icona di modifica associata';
$lang['publication']['help_det2']='Puoi eliminare questa pubblicazione cliccando sull\'icona di cancellazione associata';
$lang['publication']['help_det3']='Per visualizzare le sezioni che compongono la pubblicazione, i link associati, i documenti multimediali e le risorse bibliografiche, clicca su visualizza queste informazioni in basso nella pagina';
$lang['publication']['help_det4']='Per Aggiungere-Modificare-Eliminare le sezioni che compongono la pubblicazione, i link associati, i documenti multimediali e le risorse bibliografiche, clicca sulle icone che sono loro associate';

$lang['publication']['help_sup1']='Se non desideri confermare la cancellazione di questa pubblicazione, clicca su \'Annulla\'';


?>
